@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from django import forms
+from django.forms import TextInput
 from th_pocket.models import Pocket
 
 
@@ -13,6 +14,9 @@ class PocketForm(forms.ModelForm):
     class Meta:
         model = Pocket
         fields = ('tag',)
+        widgets = {
+            'tag': TextInput(attrs={'class': 'form-control'}),
+        }
 
 
 class PocketProviderForm(PocketForm):
