@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 import datetime
 import time
+import arrow
 
-# pocket API
+# pocket API
 import pocket
 from pocket import Pocket
 
@@ -39,40 +40,59 @@ class ServicePocket(ServicesMgr):
     def process_data(self, token, trigger_id, date_triggered):
         """
             get the data from the service
+            as the pocket service does not have any date
+            in its API linked to the note,
+            add the triggered date to the dict data
+            thus the service will be triggered when data will be found
+            :param trigger_id: trigger ID to process
+            :param date_triggered: the date of the last trigger
+            :type trigger_id: int
+            :type date_triggered: datetime
+            :return: list of data found from the date_triggered filter
+            :rtype: list
         """
-        datas = list()
+        data = list()
         # pocket uses a timestamp date format
-        date_triggered = int(
+        since = int(
             time.mktime(datetime.datetime.timetuple(date_triggered)))
 
         pocket_instance = ''
 
         if token is not None:
 
-            pocket_instance = pocket.Pocket(
+            pocket_instance = Pocket(
                 settings.TH_POCKET['consumer_key'], token)
 
             # get the data from the last time the trigger have been started
             # timestamp form
-            pockets = pocket_instance.get(since=date_triggered)
+            pockets = pocket_instance.get(since=since, state="unread")
 
-            if len(pockets[0]['list']) > 0:
+            if pockets is not None and len(pockets[0]['list']) > 0:
                 for pocket in pockets[0]['list'].values():
-
-                    datas.append({'tag': '',
-                                  'link': pocket['resolved_url'],
-                                  'title': pocket['resolved_title'],
+                    content = (pocket['excerpt'] if pocket['excerpt'] else pocket['given_title'])
+                    data.append({'my_date': str(arrow.get(str(date_triggered), 'YYYY-MM-DD HH:mm:ss').to(settings.TIME_ZONE)),
+                                  'tag': '',
+                                  'link': pocket['given_url'],
+                                  'title': pocket['given_title'],
+                                  'content': content,
                                   'tweet_id': 0})
-
-        return datas
+        return data
 
     def save_data(self, token, trigger_id, **data):
         """
             let's save the data
+
+            :param trigger_id: trigger ID from which to save data
+            :param **data: the data to check to be used and save
+            :type trigger_id: int
+            :type **data:  dict
+            :return: the status of the save statement
+            :rtype: boolean
         """
         from th_pocket.models import Pocket as PocketModel
 
         pocket_instance = ''
+        status = False
 
         if token and 'link' in data and data['link'] is not None and len(data['link']) > 0:
             # get the pocket data of this trigger
@@ -89,11 +109,15 @@ class ServicePocket(ServicesMgr):
 
                 sentence = str('pocket {} created').format(data['link'])
                 logger.debug(sentence)
+                status = True
             except Exception as e:
                 logger.critical(e)
+                status = False
 
         else:
-            logger.critical("no token provided for trigger ID %s ", trigger_id)
+            logger.critical("no token provided for trigger ID %s ", trigger_id)            
+        return status
+
 
     def auth(self, request):
         """
